@@ -463,7 +463,7 @@ class RestAPI(object):
 	def __get_plan_by_plan_id__(self, plan_id):
 		for key, value in self.__plans__.items():
 			if plan_id == value["plan_id"]: 
-				return r3sponse.success_response("Successfully retrieved the plan.". {
+				return r3sponse.success_response("Successfully retrieved the plan.", {
 					"plan":value["plan_id"],
 				})
 		return r3sponse.error_response(f"Failed to rerieve the plan name for stripe plan id [{plan_id}].")
